# Generated by Django 3.2.13 on 2022-05-03 11:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('common', '0021_school_is_active'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='school',
            name='latitude',
        ),
        migrations.RemoveField(
            model_name='school',
            name='longitude',
        ),
        migrations.RemoveField(
            model_name='school',
            name='town',
        ),
        migrations.RemoveField(
            model_name='userprofile',
            name='can_view_aggregated_data',
        ),
    ]
