# Generated by Django 3.2.13 on 2022-06-07 17:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0023_userprofile_aimmo_badges"),
    ]

    operations = [
        migrations.AddField(
            model_name="teacher",
            name="invited_by",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="invited_teachers",
                to="common.teacher",
            ),
        ),
    ]
