# Generated by Django 2.2.24 on 2021-08-18 15:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0009_add_blocked_time_to_teacher_and_student"),
        ("portal", "0062_verify_portaladmin"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="teacher",
            name="title",
        ),
    ]
