# -*- coding: utf-8 -*-
# Generated by Django 1.11.24 on 2020-09-23 10:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("common", "0002_emailverification")]

    operations = [
        migrations.CreateModel(
            name="AimmoCharacter",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255)),
                ("description", models.TextField()),
                ("image_path", models.CharField(max_length=255)),
                ("sort_order", models.IntegerField()),
            ],
        )
    ]
