# Generated by Django 2.2.24 on 2021-12-06 15:03

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0014_login_type"),
    ]

    operations = [
        migrations.CreateModel(
            name="DailyActivity",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("date", models.DateField(default=django.utils.timezone.now)),
                ("csv_click_count", models.PositiveIntegerField(default=0)),
                ("login_cards_click_count", models.PositiveIntegerField(default=0)),
            ],
        ),
    ]
